===========
Development
===========

Get the Code
------------

Sickle is developed on `GitHub <http://github.org/mloesch/sickle>`_.

Testing
-------

Sickle is tested with `nose <http://nose.readthedocs.org/en/latest/index.html>`_.

To run the tests, type:

.. code-block:: text

    python setup.py nosetests
